Re: [OE-core] [PATCH] devtool: build: add deploy to the tasks run for devtool build

2019-06-08 Thread Jaewon Lee
Sorry about that Richard 
Will be sure to test with that 

Thanks,
Jaewon


> On Jun 8, 2019, at 5:15 AM, Richard Purdie 
>  wrote:
> 
>> On Fri, 2019-06-07 at 15:17 -0700, Jaewon Lee wrote:
>> Right now `devtool build` runs populate_sysroot and packagedata
>> tasks.
>> Adding deploy to this list so that the newly built artifacts are
>> available in the deploy directory.
>> 
>> Signed-off-by: Jaewon Lee 
>> 
>> [YOCTO #13382]
>> 
>> Signed-off-by: Jaewon Lee 
>> ---
>> scripts/lib/devtool/build.py | 2 +-
>> 1 file changed, 1 insertion(+), 1 deletion(-)
>> 
>> diff --git a/scripts/lib/devtool/build.py
>> b/scripts/lib/devtool/build.py
>> index 7543398..aff5710 100644
>> --- a/scripts/lib/devtool/build.py
>> +++ b/scripts/lib/devtool/build.py
>> @@ -37,7 +37,7 @@ def _set_file_values(fn, values):
>> return updated
>> 
>> def _get_build_tasks(config):
>> -tasks = config.get('Build', 'build_task',
>> 'populate_sysroot,packagedata').split(',')
>> +tasks = config.get('Build', 'build_task',
>> 'deploy,populate_sysroot,packagedata').split(',')
>> return ['do_%s' % task.strip() for task in tasks]
>> 
>> def build(args, config, basepath, workspace):
> 
> This frustrates me a bit.
> 
> The key question you have to ask here is "What happens for recipes that
> don't have a do_deploy task?".
> 
> The answer is it breaks:
> 
> https://autobuilder.yoctoproject.org/typhoon/#/builders/56/builds/506
> 
> *Please*, when sending devtool patches, test with:
> 
> oe-selftest -r devtool
> 
> Cheers,
> 
> Richard
> 
> 
> 
> 
> 

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v2] recipetool: add python3 support

2019-06-08 Thread Maciej Pijanowski
Add support for generating python3 recipes using the recipetool / devtool.
Drop python2 support at the same time.

Tested with:

oe-selftest -r recipetool.RecipetoolTest

Fixes Bug 13264

Signed-off-by: Maciej Pijanowski 
---
 meta/lib/oeqa/selftest/cases/recipetool.py| 42 ++-
 .../lib/recipetool/create_buildsys_python.py  | 22 +-
 2 files changed, 51 insertions(+), 13 deletions(-)

diff --git a/meta/lib/oeqa/selftest/cases/recipetool.py 
b/meta/lib/oeqa/selftest/cases/recipetool.py
index f1cb37b53f8b..e3f5c71666f3 100644
--- a/meta/lib/oeqa/selftest/cases/recipetool.py
+++ b/meta/lib/oeqa/selftest/cases/recipetool.py
@@ -435,7 +435,45 @@ class RecipetoolTests(RecipetoolBase):
 checkvars = {}
 checkvars['LICENSE'] = set(['Apache-2.0'])
 checkvars['SRC_URI'] = 
'git://github.com/mesonbuild/meson;protocol=https'
-inherits = ['setuptools']
+inherits = ['setuptools3']
+self._test_recipe_contents(recipefile, checkvars, inherits)
+
+def test_recipetool_create_python3_setuptools(self):
+# Test creating python3 package from tarball (using setuptools3 class)
+temprecipe = os.path.join(self.tempdir, 'recipe')
+os.makedirs(temprecipe)
+pn = 'python-magic'
+pv = '0.4.15'
+recipefile = os.path.join(temprecipe, '%s_%s.bb' % (pn, pv))
+srcuri = 
'https://files.pythonhosted.org/packages/84/30/80932401906eaf787f2e9bd86dc458f1d2e75b064b4c187341f29516945c/python-magic-%s.tar.gz'
 % pv
+result = runCmd('recipetool create -o %s %s' % (temprecipe, srcuri))
+self.assertTrue(os.path.isfile(recipefile))
+checkvars = {}
+checkvars['LICENSE'] = set(['MIT'])
+checkvars['LIC_FILES_CHKSUM'] = 
'file://LICENSE;md5=16a934f165e8c3245f241e77d401bb88'
+checkvars['SRC_URI'] = 
'https://files.pythonhosted.org/packages/84/30/80932401906eaf787f2e9bd86dc458f1d2e75b064b4c187341f29516945c/python-magic-${PV}.tar.gz'
+checkvars['SRC_URI[md5sum]'] = 'e384c95a47218f66c6501cd6dd45ff59'
+checkvars['SRC_URI[sha256sum]'] = 
'f3765c0f582d2dfc72c15f3b5a82aecfae9498bd29ca840d72f37d7bd38bfcd5'
+inherits = ['setuptools3']
+self._test_recipe_contents(recipefile, checkvars, inherits)
+
+def test_recipetool_create_python3_distutils(self):
+# Test creating python3 package from tarball (using distutils3 class)
+temprecipe = os.path.join(self.tempdir, 'recipe')
+os.makedirs(temprecipe)
+pn = 'docutils'
+pv = '0.14'
+recipefile = os.path.join(temprecipe, '%s_%s.bb' % (pn, pv))
+srcuri = 
'https://files.pythonhosted.org/packages/84/f4/5771e41fdf52aabebbadecc9381d11dea0fa34e4759b4071244fa094804c/docutils-%s.tar.gz'
 % pv
+result = runCmd('recipetool create -o %s %s' % (temprecipe, srcuri))
+self.assertTrue(os.path.isfile(recipefile))
+checkvars = {}
+checkvars['LICENSE'] = set(['PSF', '&', 'BSD', 'GPL'])
+checkvars['LIC_FILES_CHKSUM'] = 
'file://COPYING.txt;md5=35a23d42b615470583563132872c97d6'
+checkvars['SRC_URI'] = 
'https://files.pythonhosted.org/packages/84/f4/5771e41fdf52aabebbadecc9381d11dea0fa34e4759b4071244fa094804c/docutils-${PV}.tar.gz'
+checkvars['SRC_URI[md5sum]'] = 'c53768d63db3873b7d452833553469de'
+checkvars['SRC_URI[sha256sum]'] = 
'51e64ef2ebfb29cae1faa133b3710143496eca21c530f3f71424d77687764274'
+inherits = ['distutils3']
 self._test_recipe_contents(recipefile, checkvars, inherits)
 
 def test_recipetool_create_github_tarball(self):
@@ -450,7 +488,7 @@ class RecipetoolTests(RecipetoolBase):
 checkvars = {}
 checkvars['LICENSE'] = set(['Apache-2.0'])
 checkvars['SRC_URI'] = 
'https://github.com/mesonbuild/meson/releases/download/${PV}/meson-${PV}.tar.gz'
-inherits = ['setuptools']
+inherits = ['setuptools3']
 self._test_recipe_contents(recipefile, checkvars, inherits)
 
 def test_recipetool_create_git_http(self):
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [warrior][PATCH] grub-efi-cfg, systemd-boot-cfg: use MACHINE_ARCH

2019-06-08 Thread Martin Jansa
* both use KERNEL_IMAGETYPE variable which is MACHINE specific
* fixes:

  === Comparing signatures for task do_configure.sigdata between hammerhead and 
mako ===
  ERROR: grub-bootconf different signature for task do_configure.sigdata 
between hammerhead and mako
  basehash changed from 
710332f3ec15670302dd690708730c9e418d53790ce36d6a91b049ae4f7069b1 to 
c9a46e58b4634b5fd47d20683f8320e15f5c4cb7628e3a62ed97d8528d7aabd2
  Variable KERNEL_IMAGETYPE value changed from 'zImage-dtb' to 'zImage'

  ERROR: systemd-bootconf different signature for task do_configure.sigdata 
between hammerhead and mako
  basehash changed from 
2abbaf6d7760696fbf1ff5df5705239b475ccbf6f0c831fc4031984c0ce0e9f2 to 
24f1e7886dee02b04bc180acc1c946ad82ce842655e5a5f4a8006f4a8490f985
  Variable KERNEL_IMAGETYPE value changed from 'zImage-dtb' to 'zImage'

  detected with:
  openembedded-core/scripts/sstate-diff-machines.sh --targets=world 
--tmpdir=tmp-glibc/ --analyze --machines="hammerhead mako qemux86"

Signed-off-by: Martin Jansa 
---
 meta/classes/grub-efi-cfg.bbclass | 3 +++
 meta/classes/systemd-boot-cfg.bbclass | 3 +++
 2 files changed, 6 insertions(+)

diff --git a/meta/classes/grub-efi-cfg.bbclass 
b/meta/classes/grub-efi-cfg.bbclass
index 56c2e3..f661a69f83 100644
--- a/meta/classes/grub-efi-cfg.bbclass
+++ b/meta/classes/grub-efi-cfg.bbclass
@@ -27,6 +27,9 @@ EFIDIR = "/EFI/BOOT"
 GRUB_ROOT ?= "${ROOT}"
 APPEND ?= ""
 
+# Uses MACHINE specific KERNEL_IMAGETYPE
+PACKAGE_ARCH = "${MACHINE_ARCH}"
+
 # Need UUID utility code.
 inherit fs-uuid
 
diff --git a/meta/classes/systemd-boot-cfg.bbclass 
b/meta/classes/systemd-boot-cfg.bbclass
index 021c9f9331..b3e0e6ad41 100644
--- a/meta/classes/systemd-boot-cfg.bbclass
+++ b/meta/classes/systemd-boot-cfg.bbclass
@@ -2,6 +2,9 @@ SYSTEMD_BOOT_CFG ?= "${S}/loader.conf"
 SYSTEMD_BOOT_ENTRIES ?= ""
 SYSTEMD_BOOT_TIMEOUT ?= "10"
 
+# Uses MACHINE specific KERNEL_IMAGETYPE
+PACKAGE_ARCH = "${MACHINE_ARCH}"
+
 # Need UUID utility code.
 inherit fs-uuid
 
-- 
2.17.1

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 0/1] Adding OE_EXTRA_IMPORTS

2019-06-08 Thread Chris Laplante via Openembedded-core
As explained in bitbake-devel, the motivation for adding this variable is so 
that layers have a way of using custom progress handlers. It will also be 
useful for any layer that wishes to make additional Python modules usable in 
Python functions.

Chris Laplante (1):
  base.bbclass: Add OE_EXTRA_IMPORTS

 meta/classes/base.bbclass | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

--
2.7.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [meta-oe][PATCH v3 3/4] runqemu: support non-bootable wic images

2019-06-08 Thread Richard Purdie
On Sat, 2019-06-08 at 09:59 +0200, Adrian Freihofer wrote:
> wic images are handled as vmtype images. Starting qemu with "-kernel"
> parameter and an image of type wic is not supported. Especially for
> "-machine virt" the combination of wic with -kernel parameter would
> be beneficial.
> 
> This patch changes the runqemu script to support this. If QB_MACHINE
> contains "-machine virt" and the image is of type wic a -kernel
> parameter is expected. Otherwise wic images are handled as before.
> 
> Example:
> QB_DEFAULT_FSTYPE = "wic"
> QB_KERNEL_ROOT = "/dev/vda1"
> QB_SYSTEM_NAME = "qemu-system-aarch64"
> QB_MACHINE = "-machine virt"
> ...
> 
> [YOCTO #13336]
> 
> Signed-off-by: Adrian Freihofer 

I'm afraid I don't like this at all, it feels like a horrible interface
which won't scale. The fact the machine sets QB_MACHINE to use virt has
no real relation to whether the image contains a kernel or not, it just
happens to match the current defaults.

Can we add a specific parameter which controls this explicitly?

Perhaps something like a generic "fsinfo" parameter:

QB_FSINFO = "wic:kernel-in-fs"

with wic specific information in it?

I do much prefer the wic-fs and wic-vm change though as it means more
than "wic-nb" did.

Cheers,

Richard



-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 3/3] gtk+3: update 3.24.5 -> 3.24.8

2019-06-08 Thread Richard Purdie
On Fri, 2019-06-07 at 14:19 +0200, Alexander Kanavin wrote:
> Rebase 0003-Add-disable-opengl-configure-option.patch
> 
> Signed-off-by: Alexander Kanavin 
> ---
>  ...-Add-disable-opengl-configure-option.patch | 41 ++---
> --
>  .../gtk+/{gtk+3_3.24.5.bb => gtk+3_3.24.8.bb} |  4 +-
>  2 files changed, 23 insertions(+), 22 deletions(-)
>  rename meta/recipes-gnome/gtk+/{gtk+3_3.24.5.bb => gtk+3_3.24.8.bb}
> (84%)

I retested with the date/time on the workers fixed and this series
present. We saw:

https://autobuilder.yoctoproject.org/typhoon/#/builders/47/builds/693

so I think there might be something not quite right with opengl
disabled (the main difference to nodistro I can think of?)

Cheers,

Richard

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] ✗ patchtest: failure for runqemu: support non-bootable wic images

2019-06-08 Thread Patchwork
== Series Details ==

Series: runqemu: support non-bootable wic images
Revision: 1
URL   : https://patchwork.openembedded.org/series/18051/
State : failure

== Summary ==


Thank you for submitting this patch series to OpenEmbedded Core. This is
an automated response. Several tests have been executed on the proposed
series by patchtest resulting in the following failures:



* Patch[meta-oe,v3,1/4] qemurunner: fix undefined variable
 Issue Patch is missing Signed-off-by [test_signed_off_by_presence] 
  Suggested fixSign off the patch (either manually or with "git commit 
--amend -s")



If you believe any of these test results are incorrect, please reply to the
mailing list (openembedded-core@lists.openembedded.org) raising your concerns.
Otherwise we would appreciate you correcting the issues and submitting a new
version of the patchset if applicable. Please ensure you add/increment the
version number when sending the new version (i.e. [PATCH] -> [PATCH v2] ->
[PATCH v3] -> ...).

---
Guidelines: 
https://www.openembedded.org/wiki/Commit_Patch_Message_Guidelines
Test framework: http://git.yoctoproject.org/cgit/cgit.cgi/patchtest
Test suite: http://git.yoctoproject.org/cgit/cgit.cgi/patchtest-oe

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [meta-oe][PATCH v3 1/4] qemurunner: fix undefined variable

2019-06-08 Thread Adrian Freihofer
While hacking on this I got an Exception. It's better to define
variables also in python.

Signe:-off-by: Adrian Freihofer 
---
 meta/lib/oeqa/utils/qemurunner.py | 1 +
 1 file changed, 1 insertion(+)

diff --git a/meta/lib/oeqa/utils/qemurunner.py 
b/meta/lib/oeqa/utils/qemurunner.py
index 6d2860c106..c16227fc38 100644
--- a/meta/lib/oeqa/utils/qemurunner.py
+++ b/meta/lib/oeqa/utils/qemurunner.py
@@ -60,6 +60,7 @@ class QemuRunner:
 self.runqemutime = 120
 self.qemu_pidfile = 'pidfile_'+str(os.getpid())
 self.host_dumper = HostDumper(dump_host_cmds, dump_dir)
+self.monitorpipe = None
 
 self.logger = logger
 
-- 
2.11.0

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [meta-oe][PATCH v3 4/4] runqemu: add wic-fs and wic-wm paramters

2019-06-08 Thread Adrian Freihofer
This is an optional follow up for the previous commit. It allows
to define if wic images are handled as vm or as fs type images by
command line argument.

Signed-off-by: Adrian Freihofer 
---
 scripts/runqemu | 6 ++
 1 file changed, 6 insertions(+)

diff --git a/scripts/runqemu b/scripts/runqemu
index 71894c9ca8..c730a72168 100755
--- a/scripts/runqemu
+++ b/scripts/runqemu
@@ -76,6 +76,8 @@ of the following environment variables (in any order):
 publicvnc - enable a VNC server open to all hosts
 audio - enable audio
 [*/]ovmf* - OVMF firmware file or base name for booting with UEFI
+wic-fs - Start Qemu with -kernel parameter for wic images (default if 
-machine virt)
+wic-vm - Start Qemu without -kernel parameter for wic images (default 
otherwise)
   tcpserial= - specify tcp serial port number
   biosdir= - specify custom bios dir
   biosfilename= - specify bios filename
@@ -455,6 +457,10 @@ class BaseConfig(object):
 self.rootfs = arg
 elif arg.startswith('ovmf'):
 self.ovmf_bios.append(arg)
+elif arg == 'wic-fs':
+self.wic_fs = True
+elif arg == 'wic-vm':
+self.wic_fs = False
 else:
 # At last, assume it is the MACHINE
 if (not unknown_arg) or unknown_arg == arg:
-- 
2.11.0

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [meta-oe][PATCH v3 2/4] testimage: consider QB_DEFAULT_FSTYPE

2019-06-08 Thread Adrian Freihofer
testimage.bbclass starts qemu with the first image type found in
the IMAGE_FSTYPES list. It's weird: this ['wic', 'tar'] works but
this ['tar'. 'wic'] does not. If QB_DEFAULT_FSTYPE is defined,
this fstype is booted.

Signed-off-by: Adrian Freihofer 
---
 meta/classes/testimage.bbclass | 6 +-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/meta/classes/testimage.bbclass b/meta/classes/testimage.bbclass
index 9bb5a5cb0b..525c5a6173 100644
--- a/meta/classes/testimage.bbclass
+++ b/meta/classes/testimage.bbclass
@@ -210,7 +210,11 @@ def testimage_main(d):
 bb.fatal('Unsupported image type built. Add a comptible image to '
  'IMAGE_FSTYPES. Supported types: %s' %
  ', '.join(supported_fstypes))
-rootfs = '%s.%s' % (image_name, fstypes[0])
+qfstype = fstypes[0]
+qdeffstype = d.getVar("QB_DEFAULT_FSTYPE")
+if qdeffstype:
+qfstype = qdeffstype
+rootfs = '%s.%s' % (image_name, qfstype)
 
 # Get tmpdir (not really used, just for compatibility)
 tmpdir = d.getVar("TMPDIR")
-- 
2.11.0

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [meta-oe][PATCH v3 0/4] runqemu: support non-bootable wic images

2019-06-08 Thread Adrian Freihofer
Please ignore v2. This version 3 only clears up the mess in version 2.

Resolves [Yocto 13336]
Compared to v1, no new wic-nb image type is added (this caused problems
with bitbake -c testimage).

runqemu now evaluates the QB_MACHINE setting to determine whether a wic image
should be booted as a vmtype image (kernel loaded from file passed by -kernel
option) or as a fstype image (kernel in image). If QB_MACHINE contains
"-machine virt" runqemu passes a "-kernel" parameter to qemu. Otherwise
runqemu treats the wic image as vmtype image as before. 

The last patch additionally allows the user to enforce one behavior by passing
wic-vm or wic-fs to runqemu. 


One more comment on v2: The problem with v2 probably arose because I sent the
series from a new email address before registering the address. The patches
seemed to be lost. Half an hour after registering the new e-mail address I
resent them. Then this mess appeared on the mailing list.


Adrian Freihofer (4):
  qemurunner: fix undefined variable
  testimage: consider QB_DEFAULT_FSTYPE
  runqemu: support non-bootable wic images
  runqemu: add wic-fs and wic-wm paramters

 meta/classes/testimage.bbclass|  6 +-
 meta/lib/oeqa/utils/qemurunner.py |  1 +
 scripts/runqemu   | 40 +--
 3 files changed, 40 insertions(+), 7 deletions(-)

-- 
2.11.0

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [meta-oe][PATCH v3 3/4] runqemu: support non-bootable wic images

2019-06-08 Thread Adrian Freihofer
wic images are handled as vmtype images. Starting qemu with "-kernel"
parameter and an image of type wic is not supported. Especially for
"-machine virt" the combination of wic with -kernel parameter would
be beneficial.

This patch changes the runqemu script to support this. If QB_MACHINE
contains "-machine virt" and the image is of type wic a -kernel
parameter is expected. Otherwise wic images are handled as before.

Example:
QB_DEFAULT_FSTYPE = "wic"
QB_KERNEL_ROOT = "/dev/vda1"
QB_SYSTEM_NAME = "qemu-system-aarch64"
QB_MACHINE = "-machine virt"
...

[YOCTO #13336]

Signed-off-by: Adrian Freihofer 
---
 scripts/runqemu | 34 --
 1 file changed, 28 insertions(+), 6 deletions(-)

diff --git a/scripts/runqemu b/scripts/runqemu
index af90c010da..71894c9ca8 100755
--- a/scripts/runqemu
+++ b/scripts/runqemu
@@ -185,10 +185,11 @@ class BaseConfig(object):
 self.lock_descriptor = None
 self.bitbake_e = ''
 self.snapshot = False
+self.wic_fs = None
+self.wictypes = ('wic', 'wic.vmdk', 'wic.qcow2', 'wic.vdi')
 self.fstypes = ('ext2', 'ext3', 'ext4', 'jffs2', 'nfs', 'btrfs',
 'cpio.gz', 'cpio', 'ramfs', 'tar.bz2', 'tar.gz')
-self.vmtypes = ('hddimg', 'hdddirect', 'wic', 'wic.vmdk',
-'wic.qcow2', 'wic.vdi', 'iso')
+self.vmtypes = ('hddimg', 'hdddirect', 'iso')
 self.network_device = "-device e1000,netdev=net0,mac=@MAC@"
 # Use different mac section for tap and slirp to avoid
 # conflicts, e.g., when one is running with tap, the other is
@@ -253,7 +254,7 @@ class BaseConfig(object):
 
 def check_arg_fstype(self, fst):
 """Check and set FSTYPE"""
-if fst not in self.fstypes + self.vmtypes:
+if fst not in self.fstypes + self.vmtypes + self.wictypes:
 logger.warning("Maybe unsupported FSTYPE: %s" % fst)
 if not self.fstype or self.fstype == fst:
 if fst == 'ramfs':
@@ -300,7 +301,7 @@ class BaseConfig(object):
 # Check filename against self.fstypes can hanlde .cpio.gz,
 # otherwise, its type would be "gz", which is incorrect.
 fst = ""
-for t in self.fstypes:
+for t in self.fstypes + self.wictypes:
 if p.endswith(t):
 fst = t
 break
@@ -390,7 +391,7 @@ class BaseConfig(object):
 
 unknown_arg = ""
 for arg in sys.argv[1:]:
-if arg in self.fstypes + self.vmtypes:
+if arg in self.fstypes + self.vmtypes + self.wictypes:
 self.check_arg_fstype(arg)
 elif arg == 'nographic':
 self.qemu_opt_script += ' -nographic'
@@ -695,6 +696,21 @@ class BaseConfig(object):
 
 def check_and_set(self):
 """Check configs sanity and set when needed"""
+
+# Decide how wic images are handled: as vm or with -kernel parameter
+if self.wic_fs is None:
+self.wic_fs = False
+try:
+qbm = self.get('QB_MACHINE')
+if re.search('\s+virt(?![^ ])', qbm):
+self.wic_fs = True
+except AttributeError:
+pass
+if self.wic_fs is True:
+self.fstypes = self.fstypes + self.wictypes
+else:
+self.vmtypes = self.vmtypes + self.wictypes
+
 self.validate_paths()
 if not self.slirp_enabled:
 check_tun()
@@ -832,7 +848,13 @@ class BaseConfig(object):
 if self.dtb:
 print('DTB: [%s]' % self.dtb)
 print('MACHINE: [%s]' % self.get('MACHINE'))
-print('FSTYPE: [%s]' % self.fstype)
+wic_mode = ''
+if self.fstype == 'wic':
+if self.wic_fs:
+wic_mode = ' (fs)'
+else:
+wic_mode = ' (vm)'
+print('FSTYPE: [%s%s]' % (self.fstype, wic_mode))
 if self.fstype  == 'nfs':
 print('NFS_DIR: [%s]' % self.rootfs)
 else:
diff --git a/scripts/lib/recipetool/create_buildsys_python.py 
b/scripts/lib/recipetool/create_buildsys_python.py
index 1a38bd0b14ef..ac9bc9237ce0 100644
--- a/scripts/lib/recipetool/create_buildsys_python.py
+++ b/scripts/lib/recipetool/create_buildsys_python.py
@@ -31,11 +31,11 @@ def tinfoil_init(instance):
 
 
 class PythonRecipeHandler(RecipeHandler):
-base_pkgdeps = ['python-core']
-excluded_pkgdeps = ['python-dbg']
-# os.path is provided by python-core
+base_pkgdeps = ['python3-core']
+excluded_pkgdeps = ['python3-dbg']
+# os.path is provided by python3-core
 assume_provided = ['builtins', 'os.path']
 # Assumes that the host python builtin_module_names is sane for target too
 assume_provided = assume_provided + list(sys.builtin_module_names)
 
 bbvar_map = {
@@ -215,9 +215,9 @@ class 
@@ -31,11 +31,11 @@ def tinfoil_init(instance):
 assume_provided = ['builtins', 'os.path']
-# Assumes that the host python builtin_module_names is sane for target too
+# Assumes that the host python3 builtin_module_names is sane for target too
 assume_provided = assume_provided + list(sys.builtin_module_names)
 

Re: [OE-core] [PATCH] devtool: build: add deploy to the tasks run for devtool build

2019-06-08 Thread Richard Purdie
On Fri, 2019-06-07 at 15:17 -0700, Jaewon Lee wrote:
> Right now `devtool build` runs populate_sysroot and packagedata
> tasks.
> Adding deploy to this list so that the newly built artifacts are
> available in the deploy directory.
> 
> Signed-off-by: Jaewon Lee 
> 
> [YOCTO #13382]
> 
> Signed-off-by: Jaewon Lee 
> ---
>  scripts/lib/devtool/build.py | 2 +-
>  1 file changed, 1 insertion(+), 1 deletion(-)
> 
> diff --git a/scripts/lib/devtool/build.py
> b/scripts/lib/devtool/build.py
> index 7543398..aff5710 100644
> --- a/scripts/lib/devtool/build.py
> +++ b/scripts/lib/devtool/build.py
> @@ -37,7 +37,7 @@ def _set_file_values(fn, values):
>  return updated
>  
>  def _get_build_tasks(config):
> -tasks = config.get('Build', 'build_task',
> 'populate_sysroot,packagedata').split(',')
> +tasks = config.get('Build', 'build_task',
> 'deploy,populate_sysroot,packagedata').split(',')
>  return ['do_%s' % task.strip() for task in tasks]
>  
>  def build(args, config, basepath, workspace):

This frustrates me a bit.

The key question you have to ask here is "What happens for recipes that
don't have a do_deploy task?".

The answer is it breaks:

https://autobuilder.yoctoproject.org/typhoon/#/builders/56/builds/506

*Please*, when sending devtool patches, test with:

oe-selftest -r devtool

Cheers,

Richard


-- 
2.11.0

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 0/4] Move SCons to Python 3

2019-06-08 Thread Burton, Ross
Hurrah, last time I looked at this the Py3 support wasn't quite ready yet.

Ross

On Sat, 8 Jun 2019 at 00:49, Tim Orling
 wrote:
>
> python-scons and python-scons-native are perhaps the last python2 only
> recipes in oe-core. With Python 2 going EOL in or before 2020, it's time
> to switch everything to Python 3.
>
> I updated scons.bbclass to use python3-scons-native. Tested build with serf.
>
> I also added a simple oeqa/runtime test while I was at it.
>
> I did not drop python-scons and python-scons-native, although we should
> at some point soon.
>
> [YOCTO #13381]
>
> The following changes since commit 666f6192aaa9e847ad0d920a487b82d984b58d26:
>
>   gnutls: Use the sysconfdir variable for the ca-certificates path 
> (2019-06-07 09:10:34 +0100)
>
> are available in the Git repository at:
>
>   git://git.openembedded.org/openembedded-core-contrib timo/python3-scons
>   http://cgit.openembedded.org//log/?h=timo/python3-scons
>
> Tim Orling (4):
>   python3-scons-{native}: add recipe for v3.0.5
>   scons.bbclass: use python3-scons
>   serf: switch to python3-scons-native
>   oeqa/runtime: add simple test for scons
>
>  meta/classes/scons.bbclass|  2 +-
>  meta/conf/distro/include/maintainers.inc  |  2 +
>  meta/lib/oeqa/runtime/cases/scons.py  | 37 +++
>  meta/lib/oeqa/runtime/files/SConstruct|  1 +
>  meta/lib/oeqa/runtime/files/hello.c   |  5 +++
>  .../python/python3-scons-native_3.0.5.bb  |  8 
>  .../python/python3-scons_3.0.5.bb | 29 +++
>  meta/recipes-support/serf/serf_1.3.9.bb   |  2 +-
>  8 files changed, 84 insertions(+), 2 deletions(-)
>  create mode 100644 meta/lib/oeqa/runtime/cases/scons.py
>  create mode 100644 meta/lib/oeqa/runtime/files/SConstruct
>  create mode 100644 meta/lib/oeqa/runtime/files/hello.c
>  create mode 100644 meta/recipes-devtools/python/python3-scons-native_3.0.5.bb
>  create mode 100644 meta/recipes-devtools/python/python3-scons_3.0.5.bb
>
> --
> 2.20.1
>
> --
> ___
> Openembedded-core mailing list
> Openembedded-core@lists.openembedded.org
> http://lists.openembedded.org/mailman/listinfo/openembedded-core
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core